<?php
/**
 * Looks for `search_filter_queries` in a WP_Query (pre_get_posts), and takes over the query
 * parses url args + query settings into queries to made on our own tables
 *
 * @link       http://searchandfilter.com
 * @since      3.0.0
 *
 * @package    Search_Filter
 * @subpackage Search_Filter/public
 */
namespace Search_Filter;

use Search_Filter\Features\Settings as Features_Settings;

// If this file is called directly, abort.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Features {
	public static function init() {
		add_action( 'init', array( __CLASS__, 'register_settings' ), 1 );
	}
	public static function register_settings() {
		// Register settings.
		Settings::register( 'features', Features_Settings::get_data(), Features_Settings::get_groups() );
	}
	public static function get_features() {

		$defaults        = Settings::get_section_defaults( 'features' );
		$features_option = Options::get_option_value( 'features' );
		$features        = $defaults;
		if ( $features_option ) {
			$features = wp_parse_args( json_decode( $features_option ), $defaults );
		}
		return $features;
	}
	public static function get_enabled_features() {
		$features         = self::get_features();
		$enabled_features = array();
		foreach ( $features as $feature => $enabled ) {
			if ( $enabled ) {
				$enabled_features[] = $feature;
			}
		}
		return $enabled_features;
	}
	public static function is_enabled( $feature ) {
		$features = self::get_enabled_features();
		return in_array( $feature, $features, true );
	}
}
