<?php
/**
 * Handles queries
 *
 * @link       http://searchandfilter.com
 * @since      3.0.0
 *
 * @package    Search_Filter
 */

namespace Search_Filter;

use Search_Filter\Core\CSS_Loader;
use Search_Filter\Database\Queries\Queries as Queries_Query;
use Search_Filter\Queries\Query;
use Search_Filter\Queries\Settings as Queries_Settings;

// If this file is called directly, abort.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
/**
 * A controller for managing all thigns to do with saved queries
 */
class Queries {
	/**
	 * Gets all queries records.
	 */
	/*
	 public static function get() {
		return self::find( array( 'number' => 0 ) );
	} */
	/**
	 * Initialise styles.
	 *
	 * Add default styles if none exist, attach to the CSS_Loader.
	 *
	 * @return void
	 */
	public static function init() {
		// TODO - register styles with the CSS_Loader.
		CSS_Loader::register_handler( 'queries', 'Search_Filter\\Queries::get_css' );
		add_action( 'search-filter/record/save', 'Search_Filter\\Queries::save_css', 10, 2 );

		add_action( 'init', array( __CLASS__, 'register_settings' ), 1 );
	}
	public static function register_settings() {
		// Register settings.
		Settings::register( 'queries', Queries_Settings::get_data(), Queries_Settings::get_groups() );
	}
	/**
	 * Find multiple queries by conditions
	 *
	 * @param array $conditions Column name => value pairs.
	 *
	 * @return array
	 */
	public static function find( $args = array(), $return_record = false ) {

		// Grab db instance.
		$query_args = array(
			'number'  => 10,
			'orderby' => 'date_published',
			'order'   => 'asc',
		);

		$query_args = wp_parse_args( $args, $query_args );

		// TODO - store a reference to the query with these args for re-using.
		$query   = new Queries_Query( $query_args );
		$queries = array();
		if ( $query ) {
			if ( ! $return_record ) {
				foreach ( $query->items as $record ) {
					$queries[] = Query::create_from_record( $record );
				}
			} else {
				$queries = $query->items;
			}
		}
		return $queries;
	}
	/**
	 * Finds the count of queries.
	 *
	 * @param [type] $args
	 * @return void
	 */
	public static function find_count( $args ) {
		// Grab db instance.
		$query_args = array(
			'number' => 0,
			'count'  => true,
		);
		$query_args = wp_parse_args( $args, $query_args );
		$query      = new Queries_Query( $query_args );
		return $query->found_items;
	}

	/**
	 * When saving a style preset, rebuild the CSS file.
	 *
	 * @param int $id The ID of the styles preset to save.
	 * @param int $section The section of the styles preset to save.
	 */
	public static function save_css( $id, $section ) {
		if ( $section === 'query' ) {
			CSS_Loader::save_css();
		}
	}
	/**
	 * Loop through queries and build their CSS.
	 */
	public static function get_css() {
		$css = '';
		// Loop through fields, and build their CSS.
		$all_records = self::find(
			array(
				'number' => 0,
				'status' => 'enabled',
			),
			true
		);
		if ( count( $all_records ) > 0 ) {
			foreach ( $all_records as $record ) {
				$css .= self::get_record_css( $record ) . "\r\n";
			}
		}
		return $css;
	}
	/**
	 * Generates or fetches the CSS for a single style preset.
	 *
	 * @since   3.0.0
	 *
	 * @param array $style_preset Associative array of style group data.
	 * @return string The generated CSS.
	 */
	public static function get_record_css( $record ) {
		$css  = '';
		$name = $record->get_name();
		// Use cached version.
		$cached_css = $record->get_css();
		if ( $cached_css !== '' ) {
			$css .= '/* Query: ' . esc_html( $name ) . " */\r\n";
			$css .= CSS_Loader::clean_css( $cached_css );
		}

		return $css;
	}
}
