<?php
/**
 * Fired during plugin activation
 *
 * @link       http://searchandfilter.com
 * @since      3.0.0
 *
 * @package    Search_Filter
 * @subpackage Search_Filter/Core
 */

namespace Search_Filter\Core;

// If this file is called directly, abort.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * All Gutenberg integration functionality
 */
class Sanitize {
	/**
	 * Deep cleans a var
	 *
	 * Loops through arrays recursively, sanitizing scalar values only.
	 *
	 * @param mixed $var  Var to clean.
	 * @return array
	 */
	public static function deep_clean( $var ) {
		if ( is_array( $var ) ) {
			// Don't we need to sanitize the key as well?
			$cleaned = array();
			foreach ( $var as $key => $val ) {
				$cleaned[ sanitize_text_field( $key ) ] = self::deep_clean( $val );
			}
			return $cleaned;
		} else {
			if ( is_bool( $var ) ) {
				return (bool) $var;
			}
			if ( is_int( $var ) ) {
				return (int) $var;
			}
			if ( is_float( $var ) ) {
				return (float) $var;
			}
			// Check if var is multiline or not.
			$is_multline = false;
			if ( strstr( $var, PHP_EOL ) ) {
				$is_multline = true;
			}
			// Don't allow anything except scalar or array.
			if ( ! is_scalar( $var ) ) {
				return '';
			}
			return $is_multline ? sanitize_textarea_field( $var ) : sanitize_text_field( $var );
		}
	}
	/**
	 * Pass through function for options, use sparingly.
	 *
	 * Used for optimisation to avoid repeating loops.
	 *
	 * TODO - this should be moved to a helper class.
	 *
	 * @param mixed $var The variable to pass through.
	 * @return mixed
	 */
	public static function esc_pass_through( $var ) {
		return $var;
	}

}
