<?php
/**
 * Defines the structure of the plugin data.
 *
 * @link       https://searchandfilter.com
 * @since      3.0.0
 *
 * @package    Search_Filter
 * @subpackage Search_Filter/Core
 */

namespace Search_Filter\Core;

// If this file is called directly, abort.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Defines the general Schema of the data used
 * Think post types and taxonomies
 */
class Schema {
	/**
	 * Creates the main CPTs
	 *
	 * @since    3.0.0
	 */
	public function init_db() {

		/**
		 * Instantiating the class runs update + install process (if done before
		 * `admin_init` hook has fired).
		 */
		$fields_table = new \Search_Filter\Database\Tables\Fields();
		// If the table does not exist, then create the table.
		if ( ! $fields_table->exists() ) {
			$fields_table->install();
		}

		$fields_meta_table = new \Search_Filter\Database\Tables\Fields_Meta();
		if ( ! $fields_meta_table->exists() ) {
			$fields_meta_table->install();
		}

		$queries_table = new \Search_Filter\Database\Tables\Queries();
		if ( ! $queries_table->exists() ) {
			$queries_table->install();
		}

		$queries_meta_table = new \Search_Filter\Database\Tables\Queries_Meta();
		if ( ! $queries_meta_table->exists() ) {
			$queries_meta_table->install();
		}

		$styles_table = new \Search_Filter\Database\Tables\Style_Presets();
		if ( ! $styles_table->exists() ) {
			$styles_table->install();
		}

		$styles_meta_table = new \Search_Filter\Database\Tables\Styles_Meta();
		if ( ! $styles_meta_table->exists() ) {
			$styles_meta_table->install();
		}

		$options_table = new \Search_Filter\Database\Tables\Options();
		if ( ! $options_table->exists() ) {
			$options_table->install();
		}
	}
}
