<?php
/**
 * Field settings for use in blocks and admin pages
 * TODO - probably could just be json - dynamic data
 * is fetched via the rest api.
 *
 * @link       https://searchandfilter.com
 * @since      3.0.0
 * @package    Search_Filter/Settings
 */

namespace Search_Filter\Fields;

// If this file is called directly, abort.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Class that contains the settings found in fields
 */
class Settings {
	/**
	 * Returns the settings groups (name + label)
	 *
	 * @return array
	 */
	public static function get_groups() {
		$groups_data = array(
			array(
				'name'  => 'query',
				'label' => __( 'Query integration', 'search-filter' ),
			),
			array(
				'name'    => 'styles',
				'label'   => __( 'Styles', 'search-filter' ),
				'context' => 'styles',
			),
			array(
				'name'  => 'general',
				'label' => __( 'General', 'search-filter' ),
			),
			array(
				'name'  => 'data',
				'label' => __( 'Data', 'search-filter' ),
			),
			array(
				'name'  => 'input',
				'label' => __( 'Input', 'search-filter' ),
			),
			array(
				'name'  => 'control_type',
				'label' => __( 'Type', 'search-filter' ),
			),
			array(
				'name'  => 'label',
				'label' => __( 'Label', 'search-filter' ),
			),
			array(
				'name'    => 'dimensions',
				'label'   => __( 'Dimensions', 'search-filter' ),
				'context' => 'styles',
				'type'    => 'tools-panel',
			),
			/*
			 array(
				'name'  => 'size',
				'label' => __( 'Sizing', 'search-filter' ),
			), */
			/*
			 array(
				'name'  => 'layout',
				'label' => __( 'Layout', 'search-filter' ),
			), */
			array(
				'name'  => 'advanced',
				'label' => __( 'Advanced', 'search-filter' ),
			),
		);
		return $groups_data;
	}

	/**
	 * Returns all the settings.
	 *
	 * @return array
	 */
	public static function get_data() {

		$settings_data = array();
		// order is important.
		$settings_data = array_merge( $settings_data, self::get_basic_settings() );
		$settings_data = array_merge( $settings_data, self::get_text_settings() );
		$settings_data = array_merge( $settings_data, self::get_post_type_filter_settings() );
		$settings_data = array_merge( $settings_data, self::get_post_status_filter_settings() );
		$settings_data = array_merge( $settings_data, self::get_filter_settings() );
		$settings_data = array_merge( $settings_data, self::get_taxonomy_filter_settings() );
		$settings_data = array_merge( $settings_data, self::get_range_settings() );
		$settings_data = array_merge( $settings_data, self::get_shared_settings() );
		$settings_data = array_merge( $settings_data, self::get_design_settings() );
		$settings_data = array_merge( $settings_data, self::get_layout_settings() );

		return $settings_data;
	}
	// TODO - this should be moved into a parent class and extended.
	public static function get_defaults() {
		$defaults = array();
		$settings = self::get_data();
		foreach ( $settings as $setting ) {
			$defaults[ $setting['name'] ] = isset( $setting['default'] ) ? $setting['default'] : '';
		}
		return $defaults;
	}
	public static function get_defaults_by_context( $context ) {
		$defaults = array();
		$settings = self::get_data();
		foreach ( $settings as $setting ) {
			// Ensure that type + context are set.
			if ( ! isset( $setting['context'] ) ) {
				continue;
			}
			if ( ! is_array( $setting['context'] ) ) {
				continue;
			}
			// Ff the setting has a matching context then get the default.
			if ( ! in_array( $context, $setting['context'], true ) ) {
				continue;
			}
			if ( ! isset( $setting['default'] ) ) {
				continue;
			}
			$defaults[ $setting['name'] ] = $setting['default'];
		}
		return $defaults;
	}
	/**
	 * Gets settings based on context.
	 *
	 * @param string $context The context to get settings for.
	 *
	 * @return array
	 */
	public static function get_settings_by_context( $context ) {
		$settings            = self::get_data();
		$settings_by_context = array();
		foreach ( $settings as $setting ) {
			if ( in_array( $context, $setting['context'], true ) ) {
				$settings_by_context[] = $setting;
			}
		}
		return $settings_by_context;
	}
	/**
	 * Get the basic settings for all fields.
	 */
	public static function get_basic_settings() {

		$settings = array(

			/*
				Query integration
			*/

			array(
				'name'        => 'queryId',
				'label'       => __( 'Query', 'search-filter' ),
				'group'       => 'query',
				'default'     => '',
				'type'        => 'string',
				'inputType'   => 'QuerySelect',
				'placeholder' => __( 'Choose a saved query', 'search-filter' ),
				'context'     => array( 'block/field/search', 'block/field/filter', 'block/field/control', 'admin/field/search', 'admin/field/filter', 'admin/field/control' ),
				'store'       => array(
					'route' => '/settings/options/queries',
				),
			),

			/*
			 array(
				'name'      => 'querySlot',
				'group'     => 'query',
				'type'      => 'slot',
				'context'   => array( 'block/field/search', 'block/field/filter', 'block/field/control' ),
				'dependsOn' => array(
					'relation' => 'AND',
					'rules'    => array(
						array(
							'option'  => 'queryIntegration',
							'compare' => '=',
							'value'   => 'auto',
						),
					),
				),
			),
			array(
				'name'      => 'queryLoopSlot',
				'group'     => 'query',
				'type'      => 'slot',
				'context'   => array( 'block/field/search', 'block/field/filter', 'block/field/control' ),
				'dependsOn' => array(
					'relation' => 'AND',
					'rules'    => array(
						array(
							'option'  => 'queryIntegration',
							'compare' => '=',
							'value'   => 'query_block',
						),
					),
				),
			),
			*/
			/*
			array(
				'name'      => 'id',
				'label'     => __( 'DB ID', 'search-filter' ),
				'group'     => 'general',
				'type'      => 'string',
				// 'default'          => '', // we want it to be null
				'inputType' => 'hidden',
				'context'   => array( 'admin/field', 'admin/field/search', 'admin/field/filter', 'admin/field/control' ),
			),
			array(
				'name'        => 'name',
				'label'       => __( 'Name', 'search-filter' ),
				'help'        => __( 'The name is not displayed on the frontend, it is only used for referencing.', 'search-filter' ),
				'group'       => 'general',
				'default'     => __( 'New field', 'search-filter' ),
				'type'        => 'string',
				'inputType'   => 'Text',
				// 'restrict' => '^\S+\w\S',
				'placeholder' => __( 'Enter a field name', 'search-filter' ),
				'context'     => array( 'admin/field', 'admin/field/search', 'admin/field/filter', 'admin/field/control' ),
				// like admin pages vs guteberg block
			),*/
			array(
				'name'        => 'type',
				'label'       => __( 'Field Type', 'search-filter' ),
				'group'       => 'general',
				'type'        => 'string',
				'inputType'   => 'ButtonGroup',
				'default'     => 'filter',
				'placeholder' => __( 'Select a Field Type', 'search-filter' ),
				'help'        => __( 'Changing this option will reset your data and input attributes.', 'search-filter' ),

				'context'     => array( 'admin/field', 'admin/field/search', 'admin/field/filter', 'admin/field/control' ),
				'options'     => array(
					array(
						'label' => __( 'Search', 'search-filter' ),
						'value' => 'search',
						'icon'  => 'search',
					),
					array(
						'label' => __( 'Filter', 'search-filter' ),
						'value' => 'filter',
						'icon'  => 'filter',
					),
					array(
						'label' => __( 'Control', 'search-filter' ),
						'value' => 'control',
						'icon'  => 'control',
					),
				),
				'supports'    => array(
					'previewAPI' => true,
				),
			),
			array(
				'name'        => 'label',
				'label'       => __( 'Label', 'search-filter' ),
				'group'       => 'label',
				'default'     => __( 'New field', 'search-filter' ),
				'type'        => 'string',
				'inputType'   => 'Text',
				'placeholder' => __( 'Enter a Label', 'search-filter' ),
				'context'     => array( 'admin/field', 'block/field/search', 'admin/field/search', 'admin/field/filter', 'block/field/filter', 'admin/field/control', 'block/field/control' ),
			),
			array(
				'name'      => 'showLabel',
				'label'     => __( 'Show label', 'search-filter' ),
				'help'      => __( 'If the label is not shown, it will still be available to screen readers', 'search-filter' ),
				'group'     => 'label',
				'default'   => 'yes',
				'type'      => 'string',
				'inputType' => 'Toggle',
				'context'   => array( 'admin/field', 'block/field/search', 'admin/field/search', 'admin/field/filter', 'block/field/filter' ),
				'options'   => array(
					array(
						'value' => 'yes',
						'label' => __( 'Yes', 'search-filter' ),
					),
					array(
						'value' => 'no',
						'label' => __( 'No', 'search-filter' ),
					),
				),
			),
			array(
				'name'        => 'labelScale',
				'label'       => __( 'Scale', 'search-filter' ),
				'group'       => 'label',
				'default'     => 2,
				'type'        => 'number',
				'inputType'   => 'Range',
				'context'     => array( 'admin/field', 'block/field/search', 'admin/field/search', 'admin/field/filter', 'block/field/filter' ),
				'placeholder' => __( 'Choose a scale', 'search-filter' ),
				'min'         => 1,
				'max'         => 10,
				'step'        => 1,
				'dependsOn'   => array(
					'relation' => 'AND',
					'rules'    => array(
						array(
							'option'  => 'showLabel',
							'compare' => '=',
							'value'   => 'yes',
						),
					),
				),
			),
			array(
				'name'      => 'labelSpacing',
				'label'     => __( 'Spacing', 'search-filter' ),
				'group'     => 'label',
				'default'   => '8px',
				'type'      => 'string',
				'inputType' => 'Unit',
				'units'     => array(
					array(
						'value'   => 'px',
						'label'   => 'px',
						'default' => 0,
					),
					array(
						'value'   => 'em',
						'label'   => 'em',
						'default' => 0,
					),
					array(
						'value'   => '%',
						'label'   => '%',
						'default' => 0,
					),
				),
				'context'   => array( 'admin/field', 'block/field/search', 'admin/field/search', 'admin/field/filter', 'block/field/filter' ),
				'dependsOn' => array(
					'relation' => 'AND',
					'rules'    => array(
						array(
							'option'  => 'showLabel',
							'compare' => '=',
							'value'   => 'yes',
						),
					),
				),
			),
			array(
				'name'        => 'dataType',
				'default'     => '',
				'label'       => __( 'Data Type', 'search-filter' ),
				'group'       => 'data',
				'type'        => 'string',
				'inputType'   => 'Select',
				'placeholder' => __( 'Select a Data Type', 'search-filter' ),
				'context'     => array( 'admin/field', 'admin/field/filter', 'block/field/filter' ),
				'options'     => array(
					array(
						'label' => __( 'Post Attributes', 'search-filter' ),
						'value' => 'post_attribute',
					),
					array(
						'label' => __( 'Taxonomy', 'search-filter' ),
						'value' => 'taxonomy',
					),
					// Pro.
					// array('label' => __( 'Custom Field', 'search-filter' ), 'value' => 'post_meta', 'dependsOn' => array( 'input_type' => array( 'text_search', 'text_auto_complete', 'text_number', 'select', 'select', 'radio', 'checkbox',  'date_picker', 'combobox', 'true_false', 'range_slider', 'range_date_picker', 'range_select', 'range_radio', 'range_date_picker' ) ) ),
					/*
					array('label' => __( 'ACF', 'search-filter' ), 'value' => 'plugin:acf', 'dependsOn' => array( 'input_type' => array( 'text_search', 'text_auto_complete', 'text_number', 'select', 'radio', 'checkbox',  'date_picker', 'combobox', 'true_false', 'range_slider', 'range_date_picker', 'range_select', 'range_radio', 'range_date_picker' ) ) ),
					array('label' => __( 'Relevanssi', 'search-filter' ), 'value' => 'plugin:relevanssi', 'dependsOn' => array( 'input_type' => array( 'text_search', 'text_auto_complete' ) ) ),
					array('label' => __( 'SearchWP', 'search-filter' ), 'value' => 'plugin:search_wp', 'dependsOn' => array( 'input_type' => array( 'text_search', 'text_auto_complete' ) ) ),*/
				),

				'dependsOn'   => array(
					'relation' => 'AND',
					'rules'    => array(
						array(
							'option'  => 'type',
							'compare' => '=',
							'value'   => 'filter',
						),
					),
				),
				'supports'    => array(
					'previewAPI' => true,
				),
			),
			array(
				'name'        => 'dataPostAttribute',
				'label'       => __( 'Data Source', 'search-filter' ),
				'group'       => 'data',
				'type'        => 'string',
				'inputType'   => 'Select',
				'placeholder' => __( 'Choose Post Attributes source', 'search-filter' ),
				'context'     => array( 'admin/field', 'admin/field/filter', 'block/field/filter' ),
				'options'     => array(
					array(
						'label' => __( 'Post Type', 'search-filter' ),
						'value' => 'post_type',
					),
					array(
						'label' => __( 'Post Status', 'search-filter' ),
						'value' => 'post_status',
					),
					array(
						'label' => __( 'Published Date', 'search-filter' ),
						'value' => 'post_published_date',
					),

					// TODO - add more.
					/*
					array('label' => __( 'Title', 'search-filter' ), 'value' => 'post_title' ),
					array('label' => __( 'Content', 'search-filter' ), 'value' => 'post_content' ),
					array('label' => __( 'Excerpt', 'search-filter' ), 'value' => 'post_excerpt' ),
					array('label' => __( 'Post Type', 'search-filter' ), 'value' => 'post_type' ),
					array('label' => __( 'Published Date', 'search-filter' ), 'value' => 'post_published_date' ),
					array('label' => __( 'Modified Date', 'search-filter' ), 'value' => 'post_modified_date' ),*/
				),

				'dependsOn'   => array(
					'relation' => 'AND',
					'rules'    => array(
						array(
							'option'  => 'dataType',
							'compare' => '=',
							'value'   => 'post_attribute',
						),
						array(
							'option'  => 'type',
							'compare' => '=',
							'value'   => 'filter',
						),
					),
				),
				'supports'    => array(
					'previewAPI' => true,
				),
			),
			array(
				'name'        => 'dataTaxonomy',
				'label'       => __( 'Taxonomy', 'search-filter' ),
				'help'        => __( "If you don't see your taxonomy - check that it is set to public and it is available for your post type.", 'search-filter' ),
				'group'       => 'data',
				'type'        => 'string',
				'inputType'   => 'Select',
				'placeholder' => __( 'Choose a Taxonomy', 'search-filter' ),
				'context'     => array( 'admin/field', 'admin/field/filter', 'block/field/filter' ),
				'options'     => array(),
				'store'       => array(
					'route' => '/settings/options/taxonomies',
					'args'  => array(
						'queryId',
					),
				),
				'dependsOn'   => array(
					'relation' => 'AND',
					'rules'    => array(
						array(
							'option'  => 'dataType',
							'compare' => '=',
							'value'   => 'taxonomy',
						),
						array(
							'option'  => 'type',
							'compare' => '=',
							'value'   => 'filter',
						),
					),
				),
				'supports'    => array(
					'previewAPI' => true,
				),
			),

			array(
				'name'        => 'controlType',
				'label'       => 'Control Type',
				'group'       => 'control_type',
				'type'        => 'string',
				'inputType'   => 'Select',
				'placeholder' => __( 'Choose a Control Type', 'search-filter' ),
				'context'     => array( 'admin/field', 'admin/field/control', 'block/field/control' ),
				'options'     => array(
					// array( 'label' => '', 'value' => '' ), //placeholder
					array(
						'label' => __( 'Submit', 'search-filter' ),
						'value' => 'submit',
					),
					array(
						'label' => __( 'Reset', 'search-filter' ),
						'value' => 'reset',
					),
					/*
					array(
						'label' => __( 'Sort', 'search-filter' ),
						'value' => 'sort',
					),
					array(
						'label' => __( 'Selection', 'search-filter' ),
						'value' => 'selection',
					),
					array(
						'label' => __( 'Pagination', 'search-filter' ),
						'value' => 'pagination',
					), */
				),
				'dependsOn'   => array(
					'relation' => 'AND',
					'rules'    => array(
						array(
							'option'  => 'type',
							'compare' => '=',
							'value'   => 'control',
						),
					),
				),
				'supports'    => array(
					'previewAPI' => true,
				),
			),

			array(
				'name'        => 'inputType',
				'label'       => __( 'Input Type', 'search-filter' ),
				'help'        => __( 'Choose the type of input control.', 'search-filter' ) . "\n" . __( 'Your data settings will affect the input types that are available', 'search-filter' ),
				'group'       => 'input',
				'default'     => '',
				'type'        => 'string',
				'inputType'   => 'Select',
				'placeholder' => __( 'Select an Input Type', 'search-filter' ),
				'context'     => array( 'admin/field', 'admin/field/search', 'block/field/search', 'admin/field/filter', 'block/field/filter' /* 'admin/field/control', 'block/field/control' */ ),
				'options'     => array_merge( self::get_search_input_types(), self::get_filter_input_types(), self::get_control_input_types() ),
				'supports'    => array(
					'dependantOptions' => true,
					'previewAPI'       => true,
				),
			),
		);

		return $settings;
	}

	public static function get_text_settings() {
		$settings = array(
			array(
				'name'      => 'placeholder',
				'label'     => __( 'Placeholder text', 'search-filter' ),
				'group'     => 'input',
				'default'   => '',
				'type'      => 'string',
				'inputType' => 'Text',
				'help'      => __( 'The text that appears inside the field before a user has typed anything', 'search-filter' ),
				'dependsOn' => array(
					'relation' => 'OR',
					'rules'    => array(
						array(
							'option'  => 'inputType',
							'compare' => '=',
							'value'   => 'text',
						),
						array(
							'option'  => 'inputType',
							'compare' => '=',
							'value'   => 'select',
						),
						array(
							'option'  => 'inputType',
							'compare' => '=',
							'value'   => 'date_picker',
						),
					),
				),
				'context'   => array( 'admin/field', 'block/field/search', 'admin/field/search', 'admin/field/filter', 'block/field/filter' ),
			),
		);

		return $settings;
	}

	public static function get_filter_settings() {
		$settings = array(
			array(
				'name'      => 'hideEmpty',
				'label'     => __( 'Hide options with no results', 'search-filter' ),
				'group'     => 'input',
				'default'   => 'yes',
				'type'      => 'string',
				'inputType' => 'Toggle',
				'context'   => array( 'admin/field', 'admin/field/filter', 'block/field/filter' ),
				// 'placeholder' =>  __( 'Enter an "All Items" Label', 'search-filter' ),
				'options'   => array(
					// array( 'label' => '', 'value' => '' ), //placeholder
					array(
						'label' => __( 'Yes', 'search-filter' ),
						'value' => 'yes',
					),
					array(
						'label' => __( 'No', 'search-filter' ),
						'value' => 'no',
					),
				),
				'dependsOn' => array(
					'relation' => 'AND',
					'rules'    => array(
						array(
							'option'  => 'type',
							'compare' => '=',
							'value'   => 'filter',
						),
						array(
							'relation' => 'OR',
							'rules'    => array(
								array(
									'option'  => 'dataType',
									'compare' => '=',
									'value'   => 'taxonomy',
								),
							),
						),
						array(
							'relation' => 'OR',
							'rules'    => array(
								array(
									'option'  => 'inputType',
									'compare' => '=',
									'value'   => 'select',
								),
								array(
									'option'  => 'inputType',
									'compare' => '=',
									'value'   => 'radio',
								),
								array(
									'option'  => 'inputType',
									'compare' => '=',
									'value'   => 'checkbox',
								),
								array(
									'option'  => 'inputType',
									'compare' => '=',
									'value'   => 'link',
								),
								array(
									'option'  => 'inputType',
									'compare' => '=',
									'value'   => 'button',
								),
							),
						),
					),
				),
				'supports'  => array(
					'previewAPI' => true,
				),
			),
			array(
				'name'      => 'multiple',
				'label'     => __( 'Multiple selection', 'search-filter' ),
				'group'     => 'input',
				'default'   => 'no',
				'type'      => 'string',
				'inputType' => 'Toggle',
				'context'   => array( 'admin/field', 'admin/field/filter', 'block/field/filter' ),
				'options'   => array(
					array(
						'label' => __( 'Yes', 'search-filter' ),
						'value' => 'yes',
					),
					array(
						'label' => __( 'No', 'search-filter' ),
						'value' => 'no',
					),
				),
				'dependsOn' => array(
					'relation' => 'AND',
					'rules'    => array(
						array(
							'option'  => 'type',
							'compare' => '=',
							'value'   => 'filter',
						),
						array(
							'relation' => 'OR',
							'action'   => 'hide',
							'rules'    => array(
								array(
									'option'  => 'inputType',
									'compare' => '=',
									'value'   => 'select',
								),
								array(
									'option'  => 'inputType',
									'compare' => '=',
									'value'   => 'button',
								),
							),
						),
					),
				),
			),
			array(
				'name'        => 'multipleMatchMethod',
				'label'       => __( 'Match mode', 'search-filter' ),
				'help'        => __( 'Choose whether results must match all the selected options or just one of them.', 'search-filter' ),
				'group'       => 'input',
				'type'        => 'string',
				'inputType'   => 'Select',
				'placeholder' => __( 'Choose a Taxonomy', 'search-filter' ),
				'context'     => array( 'admin/field', 'admin/field/filter', 'block/field/filter' ),
				'options'     => array(
					array(
						'label' => __( 'Match any', 'search-filter' ),
						'value' => 'any',
					),
					array(
						'label' => __( 'Match all', 'search-filter' ),
						'value' => 'all',
					),
				),
				'dependsOn'   => array(
					'relation' => 'AND',
					'rules'    => array(
						array(
							'option'  => 'dataType',
							'compare' => '=',
							'value'   => 'taxonomy',
						),
						array(
							'option'  => 'type',
							'compare' => '=',
							'value'   => 'filter',
						),
						array(
							'relation' => 'OR',
							'rules'    => array(
								array(
									'option'  => 'inputType',
									'compare' => '=',
									'value'   => 'checkbox',
								),
								array(
									'relation' => 'AND',
									'rules'    => array(
										array(
											'option'  => 'inputType',
											'compare' => '=',
											'value'   => 'select',
										),
										array(
											'option'  => 'multiple',
											'compare' => '=',
											'value'   => 'yes',
										),
									),
								),
								array(
									'relation' => 'AND',
									'rules'    => array(
										array(
											'option'  => 'inputType',
											'compare' => '=',
											'value'   => 'button',
										),
										array(
											'option'  => 'multiple',
											'compare' => '=',
											'value'   => 'yes',
										),
									),
								),

							),
						),
					),
				),
			),

			/*
			array(
				'name' => 'limit_number_options',
				'label' => __( 'Limit Number of Options Shown', 'search-filter' ),
				'group' => 'data',
				'default' => 'no',
				'inputType' => 'Select',
				'options' => array(
					array( 'label' => '', 'value' => '' ), //placeholder
					array(
						'label' => __( 'Yes', 'search-filter' ),
						'value' => 'yes',
					),
					array(
						'label' => __( 'No', 'search-filter' ),
						'value' => 'no',
					),
				),
				'placeholder' =>  __( '', 'search-filter' ),
				'dependsOn' => array(
					'relation' => 'OR',
					array(
						'option' => 'input_type',
						'compare' => '=',
						'value' => 'checkbox',
					),
					array(
						'option' => 'input_type',
						'compare' => '=',
						'value' => 'radio',
					),
					array(
						'option' => 'input_type',
						'compare' => '=',
						'value' => 'link',
					),
					array(
						'option' => 'input_type',
						'compare' => '=',
						'value' => 'button',
					),
				),
			),
			array(
				'name' => 'show_number_options',
				'label' => __( 'How many options should be shown', 'search-filter' ),
				'group' => 'data',
				'default' => '10',
				'inputType' => 'Number',
				'placeholder' =>  __( '', 'search-filter' ),
				'dependsOn' => array(
					'relation' => 'OR',
					array(
						'option' => 'limit_number_options',
						'compare' => '=',
						'value' => 'yes',
					),
				),
			),
			array(
				'name' => 'show_view_more',
				'label' => __( 'Show "View more"', 'search-filter' ),
				'group' => 'data',
				'default' => 'yes',
				'inputType' => 'Select',
				'options' => array(
					array( 'label' => '', 'value' => '' ), //placeholder
					array(
						'label' => __( 'Yes', 'search-filter' ),
						'value' => 'yes',
					),
					array(
						'label' => __( 'No', 'search-filter' ),
						'value' => 'no',
					),
				),
				'placeholder' =>  __( '', 'search-filter' ),
				'dependsOn' => array(
					'relation' => 'OR',
					array(
						'option' => 'limit_number_options',
						'compare' => '=',
						'value' => 'yes',
					),
				),
			),

			array(
				'name' => 'view_more_text',
				'label' => __( 'View More Label', 'search-filter' ),
				'group' => 'data',
				'default' => __( 'View more', 'search-filter' ),
				'inputType' => 'Text',
				'placeholder' =>  __( 'Enter an "All Items" Label', 'search-filter' ),
				'dependsOn' => array(
					'relation' => 'OR',
					array(
						'option' => 'show_view_more',
						'compare' => '=',
						'value' => 'yes',
					),
				),
			),*/
		);

		return $settings;
	}
	public static function get_taxonomy_filter_settings() {
		$settings = array(
			array(
				'name'      => 'taxonomyHierarchical',
				'label'     => __( 'Hierarchical', 'search-filter' ),
				'help'      => __( 'Indent child terms for hierarchical taxonomies', 'search-filter' ),
				'group'     => 'data',
				'default'   => 'yes',
				'type'      => 'string',
				'inputType' => 'Toggle',
				'context'   => array( 'admin/field', 'admin/field/filter', 'block/field/filter' ),
				// 'inputType' => 'Select',
				// 'multiple' => true,
				// 'placeholder' =>  __( 'Show the Option', 'search-filter' ),
				'options'   => array(
					// array( 'label' => '', 'value' => '' ), //placeholder
					array(
						'label' => __( 'Yes', 'search-filter' ),
						'value' => 'yes',
					),
					array(
						'label' => __( 'No', 'search-filter' ),
						'value' => 'no',
					),
				),
				'dependsOn' => array(
					'relation' => 'AND',
					'rules'    => array(
						array(
							'option'  => 'type',
							'compare' => '=',
							'value'   => 'filter',
						),
						array(
							'option'  => 'dataType',
							'compare' => '=',
							'value'   => 'taxonomy',
						),
					),
				),
				'supports'  => array(
					'previewAPI' => true,
				),
			),
			array(
				'name'      => 'limitTaxonomyDepth',
				'label'     => __( 'Limit hierarchical depth', 'search-filter' ),
				'group'     => 'data',
				'default'   => 'no',
				'type'      => 'string',
				// 'help'      => __( 'Limit how many levels to show.', 'search-filter' ),
				'inputType' => 'Toggle',
				'context'   => array( 'admin/field', 'admin/field/filter', 'block/field/filter' ),
				'options'   => array(
					array(
						'value' => 'yes',
						'label' => __( 'Yes', 'search-filter' ),
					),
					array(
						'value' => 'no',
						'label' => __( 'No', 'search-filter' ),
					),
				),
				'dependsOn' => array(
					'relation' => 'AND',
					'rules'    => array(
						array(
							'option'  => 'dataType',
							'compare' => '=',
							'value'   => 'taxonomy',
						),
						array(
							'option'  => 'taxonomyHierarchical',
							'compare' => '=',
							'value'   => 'yes',
						),
						array(
							'option'  => 'type',
							'compare' => '=',
							'value'   => 'filter',
						),
					),
				),
				'supports'  => array(
					'previewAPI' => true,
				),
			),
			array(
				'name'        => 'taxonomyDepth',
				'label'       => __( 'Hierarchical depth', 'search-filter' ),
				// 'help'        => __( 'Restrict terms to a hierarchical depth. Leave as `0` to display all depths.', 'search-filter' ),
				'group'       => 'data',
				'default'     => '1',
				'type'        => 'string',
				'inputType'   => 'Number',
				'placeholder' => '1',
				'context'     => array( 'admin/field', 'admin/field/filter', 'block/field/filter' ),
				'min'         => 1,
				'step'        => 1,
				'dependsOn'   => array(
					'relation' => 'AND',
					'rules'    => array(
						array(
							'option'  => 'dataType',
							'compare' => '=',
							'value'   => 'taxonomy',
						),
						array(
							'option'  => 'taxonomyHierarchical',
							'compare' => '=',
							'value'   => 'yes',
						),
						array(
							'option'  => 'type',
							'compare' => '=',
							'value'   => 'filter',
						),
						array(
							'option'  => 'limitTaxonomyDepth',
							'compare' => '=',
							'value'   => 'yes',
						),
					),
				),
				'supports'    => array(
					'previewAPI' => true,
				),
			),
			array(
				'name'      => 'taxonomyOrderBy',
				'label'     => __( 'Order Terms By', 'search-filter' ),
				'group'     => 'data',
				'default'   => 'yes',
				'type'      => 'string',
				'inputType' => 'Select',
				'context'   => array( 'admin/field', 'admin/field/filter', 'block/field/filter' ),
				'options'   => array(
					array(
						'label' => __( 'Default', 'search-filter' ),
						'value' => 'default',
					),
					array(
						'label' => __( 'ID', 'search-filter' ),
						'value' => 'id',
					),
					array(
						'label' => __( 'Name', 'search-filter' ),
						'value' => 'name',
					),
					array(
						'label' => __( 'Slug', 'search-filter' ),
						'value' => 'slug',
					),
					array(
						'label' => __( 'Count', 'search-filter' ),
						'value' => 'count',
					),
					array(
						'label' => __( 'Term Group', 'search-filter' ),
						'value' => 'term_group',
					),
				),
				'dependsOn' => array(
					'relation' => 'AND',
					'rules'    => array(
						array(
							'option'  => 'type',
							'compare' => '=',
							'value'   => 'filter',
						),
						array(
							'option'  => 'dataType',
							'compare' => '=',
							'value'   => 'taxonomy',
						),
					),
				),
				'supports'  => array(
					'previewAPI' => true,
				),
			),
			array(
				'name'      => 'taxonomyOrderDir',
				'label'     => __( 'Order Direction', 'search-filter' ),
				// 'help' => __( '', 'search-filter' ),
				'group'     => 'data',
				'default'   => 'yes',
				'type'      => 'string',
				'inputType' => 'Select',
				'context'   => array( 'admin/field', 'admin/field/filter', 'block/field/filter' ),
				'options'   => array(
					// array( 'label' => '', 'value' => '' ), //placeholder
					array(
						'label' => __( 'Default', 'search-filter' ),
						'value' => 'default',
					),
					array(
						'label' => __( 'Ascending', 'search-filter' ),
						'value' => 'asc',
					),
					array(
						'label' => __( 'Descending', 'search-filter' ),
						'value' => 'desc',
					),
				),
				// Faster to depend on the existence of another field, only 1 check needed.
				'dependsOn' => array(
					'relation' => 'AND',
					'rules'    => array(
						array(
							'option'  => 'type',
							'compare' => '=',
							'value'   => 'filter',
						),
						array(
							'option'  => 'dataType',
							'compare' => '=',
							'value'   => 'taxonomy',
						),
					),
				),
				'supports'  => array(
					'previewAPI' => true,
				),
			),
			array(
				'name'      => 'taxonomyFilterArchive',
				'label'     => __( 'Use archive URL', 'search-filter' ),
				// TODO - we need only make this available if the input type is a single select...??
				'help' => __( 'Enabling this option will use the taxonomy archive URL', 'search-filter' ),
				'group'     => 'data',
				'default'   => 'no',
				'type'      => 'string',
				'inputType' => 'Toggle',
				'context'   => array( 'admin/field', 'admin/field/filter', 'block/field/filter' ),
				'options'   => array(
					array(
						'value' => 'yes',
						'label' => __( 'Yes', 'search-filter' ),
					),
					array(
						'value' => 'no',
						'label' => __( 'No', 'search-filter' ),
					),
				),
				// Faster to depend on the existence of another field, only 1 check needed.
				'dependsOn' => array(
					'relation' => 'AND',
					'rules'    => array(
						array(
							'option'  => 'type',
							'compare' => '=',
							'value'   => 'filter',
						),
						array(
							'option'  => 'dataType',
							'compare' => '=',
							'value'   => 'taxonomy',
						),
						array(
							'relation' => 'AND',
							'rules'    => array(
								array(
									'option'  => 'inputType',
									'compare' => '!=',
									'value'   => 'checkbox',
								),
								array(
									'relation' => 'OR',
									'rules'    => array(
										array(
											'relation' => 'AND',
											'rules'    => array(
												array(
													'option'  => 'inputType',
													'compare' => '=',
													'value'   => 'select',
												),
												array(
													'option'  => 'multiple',
													'compare' => '=',
													'value'   => 'no',
												),
											),
										),
										array(
											'relation' => 'AND',
											'rules'    => array(
												array(
													'option'  => 'inputType',
													'compare' => '=',
													'value'   => 'button',
												),
												array(
													'option'  => 'multiple',
													'compare' => '=',
													'value'   => 'no',
												),
											),
										),
										array(
											'relation' => 'AND',
											'rules'    => array(
												array(
													'option'  => 'inputType',
													'compare' => '!=',
													'value'   => 'checkbox',
												),
												array(
													'option'  => 'inputType',
													'compare' => '!=',
													'value'   => 'select',
												),
												array(
													'option'  => 'inputType',
													'compare' => '!=',
													'value'   => 'button',
												),
											),
										),
									),
								),
								
							),
						),
					),
				),
				'supports'  => array(
					'previewAPI' => true,
				),
			),
		);

		return $settings;
	}

	public static function get_post_type_filter_settings() {
		$settings = array(
			array(
				// Block.json attributes.
				'name'        => 'postTypes',
				'type'        => 'array',
				'items'       => array(
					'type' => 'string',
				),
				'default'     => array(),
				'inputType'   => 'MultiSelect',
				// End block.json attributes
				/*
				 'type'      => 'string',
				'default' => '',
				'inputType' => 'Select',*/
				'label'       => __( 'Posts Types', 'search-filter' ),
				// 'placeholder' => __( 'All available post types', 'search-filter' ),
				'placeholder' => __( 'Choose post types', 'search-filter' ),
				'help'        => __( 'Leave empty to choose all available post types.  Available post types are controlled by your query settings.', 'search-filter' ),
				'group'       => 'data',
				'context'     => array( 'admin/field', 'admin/field/filter', 'block/field/filter' ),
				// 'multiple' => true,
				'options'     => array(),
				'dependsOn'   => array(
					'relation' => 'AND',
					'rules'    => array(
						array(
							'option'  => 'type',
							'compare' => '=',
							'value'   => 'filter',
						),
						array(
							'option'  => 'dataType',
							'compare' => '=',
							'value'   => 'post_attribute',
						),
						array(
							'option'  => 'dataPostAttribute',
							'compare' => '=',
							'value'   => 'post_type',
						),
					),
				),
				'store'       => array(
					'route' => '/settings/options/post-types',
					'args'  => array(
						'queryId',
					),
				),
				'supports'    => array(
					'previewAPI' => true,
				),
			),

		);
		return $settings;
	}
	public static function get_post_status_filter_settings() {
		$settings = array(
			array(
				'name'      => 'postStati',
				'label'     => __( 'Post Status', 'search-filter' ),
				'type'      => 'array',
				'items'     => array(
					'type' => 'string',
				),
				'inputType' => 'MultiSelect',
				'group'     => 'data',
				'options'   => array(),
				'default'   => array( 'publish' ),
				'context'   => array( 'admin/field', 'admin/field/filter', 'block/field/filter' ),
				'dependsOn' => array(
					'relation' => 'AND',
					'rules'    => array(
						array(
							'option'  => 'type',
							'compare' => '=',
							'value'   => 'filter',
						),
						array(
							'option'  => 'dataType',
							'compare' => '=',
							'value'   => 'post_attribute',
						),
						array(
							'option'  => 'dataPostAttribute',
							'compare' => '=',
							'value'   => 'post_status',
						),
					),
				),
				'store'     => array(
					'route' => '/settings/options/post-stati',
				),
				'supports'  => array(
					'previewAPI' => true,
				),
			),

		);

		return $settings;
	}

	public static function get_range_settings() {

		$settings = array();

		return $settings;
	}


	public static function get_shared_settings() {

		$settings = array(

			/*
			 date stuff */
			/*
			 array(
				'name'        => 'default_date',
				'label'       => __( 'Default Date', 'search-filter' ),
				'group'         => 'data',
				'default'     => 'none',
				'inputType'        => 'Select',
				'placeholder' =>  __( 'Choose a default date', 'search-filter' ),
				'options'     => array(
					array(
						'label' => __( 'None', 'search-filter' ),
						'value' => 'none',
					),
					array(
						'label' => __( 'Today', 'search-filter' ),
						'value' => 'today',
					),
					array(
						'label' => __( 'Tomorrow', 'search-filter' ),
						'value' => 'tomorrow',
					),
					array(
						'label' => __( 'Yesterday', 'search-filter' ),
						'value' => 'tomorrow',
					),
					array(
						'label' => __( 'Custom', 'search-filter' ),
						'value' => 'custom',
					),
				),
				'dependsOn' => array(
					'relation' => 'AND',
					array(
						'option'  => 'dataPostAttribute',
						'compare' => '=',
						'value'   => 'post_published_date',
					),
				),
			), */
			array(
				'name'        => 'dateDisplayFormat',
				'label'       => __( 'Display format', 'search-filter' ),
				'group'       => 'input',
				'default'     => '',
				'type'        => 'string',
				'inputType'   => 'Select',
				'context'     => array( 'admin/field', 'admin/field/filter', 'block/field/filter' ),
				'placeholder' => __( 'Choose a date format for displaying', 'search-filter' ),

				'options'     => array(
					array(
						'label' => 'F j, Y',
						'value' => 'F j, Y',
					),
					array(
						'label' => 'Y-m-d',
						'value' => 'Y-m-d',
					),
					array(
						'label' => 'm/d/Y',
						'value' => 'm/d/Y',
					),
					array(
						'label' => 'd/m/Y',
						'value' => 'd/m/Y',
					),
					array(
						'label' => 'Custom',
						'value' => 'custom',
					),
				),
				'dependsOn'   => array(
					'relation' => 'AND',
					'rules'    => array(
						array(
							'option'  => 'inputType',
							'value'   => 'date_picker',
							'compare' => '=',
						),
					),
				),
			),
			array(
				'name'        => 'dateDisplayFormatCustom',
				'label'       => 'Custom format',
				'group'       => 'input',
				'default'     => 'F j, Y',
				'type'        => 'string',
				'inputType'   => 'Text',
				'context'     => array( 'admin/field', 'admin/field/filter', 'block/field/filter' ),
				'placeholder' => __( 'Enter a custom format for displaying the date.', 'search-filter' ),
				'dependsOn'   => array(
					'relation' => 'AND',
					'rules'    => array(
						array(
							'option'  => 'inputType',
							'value'   => 'date_picker',
							'compare' => '=',
						),
						array(
							'option'  => 'dateDisplayFormat',
							'value'   => 'custom',
							'compare' => '=',
						),
					),
				),
			),
			array(
				'name'      => 'dateShowMonth',
				'label'     => __( 'Show Month Dropdown', 'search-filter' ),
				'group'     => 'input',
				'default'   => 'no',
				'type'      => 'string',
				'inputType' => 'Toggle',
				'context'   => array( 'admin/field', 'admin/field/filter', 'block/field/filter' ),
				'options'   => array(
					array(
						'value' => 'yes',
						'label' => __( 'Yes', 'search-filter' ),
					),
					array(
						'value' => 'no',
						'label' => __( 'No', 'search-filter' ),
					),
				),
				'dependsOn' => array(
					'relation' => 'AND',
					'rules'    => array(
						array(
							'option'  => 'inputType',
							'value'   => 'date_picker',
							'compare' => '=',
						),
					),
				),
			),
			array(
				'name'      => 'dateShowYear',
				'label'     => __( 'Show Year Dropdown', 'search-filter' ),
				'group'     => 'input',
				'default'   => 'no',
				'type'      => 'string',
				'inputType' => 'Toggle',
				'context'   => array( 'admin/field', 'admin/field/filter', 'block/field/filter' ),
				'options'   => array(
					array(
						'value' => 'yes',
						'label' => __( 'Yes', 'search-filter' ),
					),
					array(
						'value' => 'no',
						'label' => __( 'No', 'search-filter' ),
					),
				),
				'dependsOn' => array(
					'relation' => 'AND',
					'rules'    => array(
						array(
							'option'  => 'inputType',
							'value'   => 'date_picker',
							'compare' => '=',
						),
					),
				),
			),
			array(
				'name'        => 'addClass',
				'label'       => __( 'Add a class', 'search-filter' ),
				'help'        => __( 'Separate class names with a space', 'search-filter' ),
				'default'     => '',
				'group'       => 'advanced',
				'type'        => 'string',
				'inputType'   => 'Text',
				'context'     => array( 'admin/field', 'admin/field/search', 'admin/field/filter', 'admin/field/control' ),
				'placeholder' => __( 'Add a CSS class to the field', 'search-filter' ),
			),
		);

		return $settings;
	}

	public static function get_design_settings() {

		$color_picker_colors = array(

			array(
				'name'  => 'red',
				'color' => '#f00',
			),
			array(
				'name'  => 'white',
				'color' => '#fff',
			),
			array(
				'name'  => 'blue',
				'color' => '#00f',
			),
		);

		// TODO - move over to store
		/*
		if( get_theme_support( 'editor-color-palette' ) ) {
			$theme_colors = get_theme_support( 'editor-color-palette' );
			$updated_theme_colors = $theme_colors[0];
			$color_picker_colors = array_merge( $color_picker_colors, $updated_theme_colors );
		}*/
		$settings = array(
			/*
			array(
				'name' => 'sync_with_group',
				'label' => __( 'Sync with Group Settings', 'search-filter' ),
				'group' => 'design',
				'default' => 'medium',
				'inputType'        => 'Toggle',
				'options'     => array(
					array(
						'value' => 'yes',
						'label' => __( 'Yes', 'search-filter' ),
					),
					array(
						'value' => 'no',
						'label' => __( 'No', 'search-filter' ),
					),
				),
			),*/
			array(
				'name'        => 'stylesId',
				'label'       => __( 'Styles preset', 'search-filter' ),
				'group'       => 'styles',
				'default'     => '0',
				'type'        => 'string',
				'inputType'   => 'StylesSelect',
				'context'     => array( 'admin/field', 'block/field/search', 'admin/field/search', 'admin/field/filter', 'block/field/filter', 'admin/field/control', 'block/field/control' ),
				'placeholder' => __( 'Select styles to apply', 'search-filter' ),
				'store'       => array(
					'route' => '/settings/options/styles',
				),
			),
			array(
				'name'        => 'scale',
				'label'       => __( 'Scale', 'search-filter' ),
				'group'       => 'dimensions',
				'default'     => 2,
				'type'        => 'number',
				'inputType'   => 'Range',
				'context'     => array( 'admin/field', 'block/field/search', 'admin/field/search', 'admin/field/filter', 'block/field/filter', 'admin/field/control', 'block/field/control' ),
				'placeholder' => __( 'Choose a scale', 'search-filter' ),
				'min'         => 1,
				'max'         => 10,
				'step'        => 1,
			),
			array(
				'name'             => 'width',
				'label'            => __( 'Width', 'search-filter' ),
				'group'            => 'dimensions',
				'default'          => '',
				'type'             => 'string',
				'inputType'        => 'ButtonGroup',
				'context'          => array( 'admin/field', 'block/field/search', 'admin/field/search', 'admin/field/filter', 'block/field/filter', 'admin/field/control', 'block/field/control' ),
				'requireSelection' => false,
				'options'          => array(
					array(
						'label' => __( '25%', 'search-filter' ),
						'value' => '25',
					),
					array(
						'label' => __( '50%', 'search-filter' ),
						'value' => '50',
					),
					array(
						'label' => __( '75%', 'search-filter' ),
						'value' => '75',
					),
					array(
						'label' => __( '100%', 'search-filter' ),
						'value' => '100',
					),
				),
			),
			array(
				'name'      => 'showIcon',
				'label'     => __( 'Show icon', 'search-filter' ),
				'group'     => 'input',
				'default'   => 'yes',
				'type'      => 'string',
				'inputType' => 'Toggle',
				'context'   => array( 'admin/field', 'block/field/search', 'admin/field/search', 'admin/field/filter', 'block/field/filter', 'admin/field/control', 'block/field/control' ),
				'options'   => array(
					array(
						'value' => 'yes',
						'label' => __( 'Yes', 'search-filter' ),
					),
					array(
						'value' => 'no',
						'label' => __( 'No', 'search-filter' ),
					),
				),
				'dependsOn' => array(
					'relation' => 'OR',
					'rules'    => array(
						array(
							'option'  => 'inputType',
							'compare' => '=',
							'value'   => 'text',
						),
						array(
							'option'  => 'inputType',
							'compare' => '=',
							'value'   => 'date_picker',
						),
					),
				),
			),
		);

		return $settings;
	}
	public static function get_layout_settings() {

		$settings = array(
			array(
				'name'        => 'align',
				'label'       => __( 'Align', 'search-filter' ),
				'group'       => 'layout',
				'default'     => '',
				'type'        => 'string',
				'inputType'   => 'Text',
				'context'     => array( 'admin/field', 'block/field/search', 'admin/field/search', 'admin/field/filter', 'block/field/filter', 'admin/field/control', 'block/field/control' ),
				'placeholder' => __( 'Align the field inside its container.', 'search-filter' ),
			),
			array(
				'name'        => 'alignment',
				'label'       => __( 'Alignment', 'search-filter' ),
				'group'       => 'layout',
				'default'     => '',
				'type'        => 'string',
				'inputType'   => 'Text',
				'context'     => array( 'admin/field', 'block/field/search', 'admin/field/search', 'admin/field/filter', 'block/field/filter', 'admin/field/control', 'block/field/control' ),
				'placeholder' => __( 'Align the field inside its container.', 'search-filter' ),
			),
			array(
				'name'        => 'margin',
				'label'       => __( 'Margin', 'search-filter' ),
				'group'       => 'dimensions',
				'default'     => '',
				'type'        => 'string',
				'inputType'   => 'Box',
				'allowReset'  => false,
				'context'     => array( 'admin/field', 'block/field/search', 'admin/field/search', 'admin/field/filter', 'block/field/filter', 'admin/field/control', 'block/field/control' ),
				'placeholder' => __( '.', 'search-filter' ),
			),
		);
		return $settings;
	}
	public static function get_filter_input_types() {

		$filter_depends = array(
			'relation' => 'AND',
			'action'   => 'hide',
			'rules'    => array(
				array(
					'option'  => 'type',
					'value'   => 'filter',
					'compare' => '=',
				),
				array(
					'relation' => 'OR',
					'action'   => 'hide',
					'rules'    => array(
						array(
							'option'  => 'dataType',
							'value'   => 'taxonomy',
							'compare' => '=',
						),
						array(
							'relation' => 'AND',
							'action'   => 'hide',
							'rules'    => array(
								array(
									'option'  => 'dataType',
									'value'   => 'post_attribute',
									'compare' => '=',
								),
								array(
									'relation' => 'OR',
									'action'   => 'hide',
									'rules'    => array(
										array(
											'option'  => 'dataPostAttribute',
											'value'   => 'post_type',
											'compare' => '=',
										),
										array(
											'option'  => 'dataPostAttribute',
											'value'   => 'post_status',
											'compare' => '=',
										),
									),
								),
							),
						),
					),
				),
			),
		);

		$link_button_depends = $filter_depends;

		$input_types = array(
			array(
				'value'     => 'select',
				'label'     => __( 'Select', 'search-filter' ),
				'dependsOn' => $filter_depends,
			),
			array(
				'value'     => 'radio',
				'label'     => __( 'Radio', 'search-filter' ),
				'dependsOn' => $filter_depends,
			),
			array(
				'value'     => 'checkbox',
				'label'     => __( 'Checkbox', 'search-filter' ),
				'dependsOn' => $filter_depends,
			),
			array(
				'value'     => 'button',
				'label'     => __( 'Button', 'search-filter' ),
				'dependsOn' => $filter_depends,
			),
			array(
				'value'     => 'date_picker',
				'label'     => __( 'Date Picker', 'search-filter' ),
				'dependsOn' => array(
					'relation' => 'AND',
					'action'   => 'hide',
					'rules'    => array(
						array(
							'option'  => 'type',
							'value'   => 'filter',
							'compare' => '=',
						),
						array(
							'relation' => 'AND',
							'action'   => 'hide',
							'rules'    => array(
								array(
									'option'  => 'dataType',
									'value'   => 'post_attribute',
									'compare' => '=',
								),
								array(
									'option'  => 'dataPostAttribute',
									'value'   => 'post_published_date',
									'compare' => '=',
								),
							),

						),

					),
				),
			),
		);
		return $input_types;
	}
	public static function get_control_input_types() {
		$control_submit_depends = array(
			'relation' => 'AND',
			'action'   => 'hide',
			'rules'    => array(
				array(
					'option'  => 'type',
					'value'   => 'control',
					'compare' => '=',
				),
			),
		);

		return array();
	}
	public static function get_search_input_types() {
		$search_submit_depends = array(
			'relation' => 'AND',
			'action'   => 'hide',
			'rules'    => array(
				array(
					'option'  => 'type',
					'value'   => 'search',
					'compare' => '=',
				),
			),
		);

		$input_types = array(
			array(
				'value'     => 'text',
				'label'     => __( 'Text', 'search-filter' ),
				'dependsOn' => $search_submit_depends,
			),
		);

		return $input_types;
	}
}
