<?php
/**
 * Text Search Class
 *
 * @link       https://searchandfilter.com
 * @since      3.0.0
 * @package    Search_Filter
 * @subpackage Search_Filter/Fields/Filter
 */

namespace Search_Filter\Fields\Search;

use Search_Filter\Fields\Search;

/**
 * Generates the markup for a Text field
 */
class Text extends Search {

	public $icons = array(
		'search',
		'clear',
	);
	public function get_default_attributes() {
		// TODO - defaults should be set based on the fields settings.
		// We need to apply the `dependsOn`/ conditional logic to get the necessary defaults.
		// We should probably also "clean" the attributes before saving to remove settings/keys
		// that are not needed anymore by the field.
		$defaults         = \Search_Filter\Fields\Settings::get_defaults_by_context( 'admin/field/search' );
		$defaults['type'] = 'filter';
		return $defaults;
	}
	/**
	 * Override the init and setup render data + escaping functions.
	 *
	 * @since    3.0.0
	 */
	public function init() {
		parent::init();
		$value       = $this->get_value();
		$render_data = array(
			'uid'   => self::get_instance_id( 'text' ),
			'value' => $value,
		);
		$this->set_render_data( $render_data );

		$esc_callbacks = array(
			'uid'         => 'absint',
			'value'       => 'esc_attr',
			'placeholder' => 'esc_attr',
		);
		$this->set_render_escape_callbacks( $esc_callbacks );
	}

	/**
	 * Gets the URL name for the field.
	 *
	 * @return string
	 */
	public function get_url_name() {
		if ( ! $this->has_init() ) {
			return parent::get_url_name();
		}
		return 's';
	}

	/**
	 * Parses a value from the URL.
	 */
	public function parse_url_value() {
		$url_param_name = self::url_prefix() . $this->get_url_name();
		$value          = isset( $_GET[ $url_param_name ] ) ? urldecode_deep( wp_unslash( $_GET[ $url_param_name ] ) ) : '';
		if ( $value !== '' ) {
			$this->set_values( array( $value ) );
		}
	}

	/**
	 * Gets the WP_Query args based on the field value.
	 */
	public function apply_wp_query_args( $query_args = array() ) {
		// TODO - check if the value is in the URL, and dont apply it if it isn't.
		// TODO - we should do this to all fields.
		$query_args['s'] = $this->get_value();
		return parent::apply_wp_query_args( $query_args );
	}
}
