<?php
/**
 * Field settings for use in blocks and admin pages
 * TODO - probably could just be json - we've removed dependencies on saved settings
 * and fetch things via the rest api instead.
 *
 * @link       https://searchandfilter.com
 * @since      3.0.0
 * @package    Search_Filter/Settings
 */

namespace Search_Filter\Styles;

// If this file is called directly, abort.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Class that contains the settings found for styles
 */
class Settings {
	/**
	 * Returns the settings groups (name + label)
	 *
	 * @return array
	 */
	public static function get_groups() {
		$groups_data = array();
		return $groups_data;
	}

	// TODO - this should be moved into a parent class and extended.
	public static function get_defaults() {
		$defaults = array();
		$settings = self::get_data();
		foreach ( $settings as $setting ) {
			$defaults[ $setting['name'] ] = isset( $setting['default'] ) ? $setting['default'] : '';
		}
		return $defaults;
	}
	/**
	 * Returns all the settings.
	 *
	 * @return array
	 */
	public static function get_data() {

		$settings_data = array(
			array(
				'name'      => 'textColor',
				'label'     => __( 'Text', 'search-filter' ),
				'group'     => 'design',
				'default'   => '#3c434a',
				'type'      => 'string',
				'inputType' => 'ColorPalette',
				'clearable' => 'true',
			),
			array(
				'name'      => 'backgroundColor',
				'label'     => __( 'Background', 'search-filter' ),
				'group'     => 'design',
				'default'   => '#ffffff',
				'type'      => 'string',
				'inputType' => 'ColorPalette',
				'clearable' => 'true',
			),
			array(
				'name'      => 'activeTextColor',
				'label'     => __( 'Active Text', 'search-filter' ),
				'group'     => 'design',
				'default'   => '#ffffff',
				'type'      => 'string',
				'inputType' => 'ColorPalette',
				'clearable' => 'true',
			),
			array(
				'name'      => 'activeBackgroundColor',
				'label'     => __( 'Active Background', 'search-filter' ),
				'group'     => 'design',
				'default'   => '#167de4',
				'type'      => 'string',
				'inputType' => 'ColorPalette',
				'clearable' => 'true',
			),
			array(
				'name'      => 'labelTextColor',
				'label'     => __( 'Label Text', 'search-filter' ),
				'group'     => 'design',
				'default'   => '#3c434a',
				'type'      => 'string',
				'inputType' => 'ColorPalette',
				'clearable' => 'true',
			),
			array(
				'name'      => 'secondaryColor',
				'label'     => __( 'Secondary', 'search-filter' ),
				'group'     => 'design',
				'default'   => '#3c434a',
				'type'      => 'string',
				'inputType' => 'ColorPalette',
				'clearable' => 'true',
			),
			array(
				'name'      => 'primaryAccentColor',
				'label'     => __( 'Primary Accent', 'search-filter' ),
				'group'     => 'design',
				'default'   => '#bbbbbb',
				'clearable' => 'true',
				'type'      => 'string',
				'inputType' => 'ColorPalette',
			),
			array(
				'name'      => 'secondaryAccentColor',
				'label'     => __( 'Secondary Accent', 'search-filter' ),
				'group'     => 'design',
				'default'   => '#888888',
				'clearable' => 'true',
				'type'      => 'string',
				'inputType' => 'ColorPalette',
			),
			array(
				'name'      => 'tertiaryAccentColor',
				'label'     => __( 'Tertiary Accent', 'search-filter' ),
				'group'     => 'design',
				'default'   => '#333333',
				'clearable' => 'true',
				'type'      => 'string',
				'inputType' => 'ColorPalette',
			),
		);
		return $settings_data;
	}
	/**
	 * Gets settings based on context.
	 *
	 * @param string $context The context to get settings for.
	 *
	 * @return array
	 */
	public static function get_settings_by_context( $context ) {
		$settings            = self::get_data();
		$settings_by_context = array();
		foreach ( $settings as $setting ) {
			if ( in_array( $context, $setting['context'], true ) ) {
				$settings_by_context[] = $setting;
			}
		}
		return $settings_by_context;
	}
}
